summaryrefslogtreecommitdiff
path: root/sys/dev/ic
diff options
context:
space:
mode:
authormjacob <mjacob@cvs.openbsd.org>2001-01-09 03:29:33 +0000
committermjacob <mjacob@cvs.openbsd.org>2001-01-09 03:29:33 +0000
commit22ad8b1b0532e695859f8e605eebc99ff0a1408e (patch)
treec11203da26fc86a10189951c711b262982cc7235 /sys/dev/ic
parent46c45d91b6975f2b84bc2470c9b3db14ebc2c802 (diff)
Add in a ISP_CFG_NOINIT flag (other platform stuff). Define some of
the async code event changes. Note (for __GNUC__) that isp_prt has __attributes__'s of __format__/__printf__....
Diffstat (limited to 'sys/dev/ic')
-rw-r--r--sys/dev/ic/ispvar.h16
1 files changed, 11 insertions, 5 deletions
diff --git a/sys/dev/ic/ispvar.h b/sys/dev/ic/ispvar.h
index d7a96e7f3eb..e4689be3d0a 100644
--- a/sys/dev/ic/ispvar.h
+++ b/sys/dev/ic/ispvar.h
@@ -1,4 +1,4 @@
-/* $OpenBSD: ispvar.h,v 1.13 2000/12/06 01:07:23 mjacob Exp $ */
+/* $OpenBSD: ispvar.h,v 1.14 2001/01/09 03:29:32 mjacob Exp $ */
/*
* Soft Definitions for for Qlogic ISP SCSI adapters.
*
@@ -390,6 +390,7 @@ typedef struct ispsoftc {
*/
#define ISP_CFG_NORELOAD 0x80 /* don't download f/w */
#define ISP_CFG_NONVRAM 0x40 /* ignore NVRAM */
+#define ISP_CFG_NOINIT 0x20 /* just set defaults- don't init */
#define ISP_CFG_FULL_DUPLEX 0x01 /* Full Duplex (Fibre Channel only) */
#define ISP_CFG_OWNWWN 0x02 /* override NVRAM wwn */
#define ISP_CFG_PORT_PREF 0x0C /* Mask for Port Prefs (2200 only) */
@@ -514,7 +515,6 @@ int isp_control __P((struct ispsoftc *, ispctl_t, void *));
* (each platform must provide such a function)
*
* Assumes all locks are held and that no reentrancy issues need be dealt with.
- *
*/
typedef enum {
@@ -522,9 +522,9 @@ typedef enum {
ISPASYNC_BUS_RESET, /* Bus Was Reset */
ISPASYNC_LOOP_DOWN, /* FC Loop Down */
ISPASYNC_LOOP_UP, /* FC Loop Up */
- ISPASYNC_PDB_CHANGED, /* FC Port Data Base Changed */
- ISPASYNC_CHANGE_NOTIFY, /* FC SNS Change Notification */
- ISPASYNC_FABRIC_DEV, /* FC New Fabric Device */
+ ISPASYNC_CHANGE_NOTIFY, /* FC SNS or Port Database Changed */
+ ISPASYNC_FABRIC_DEV, /* FC Fabric Device Arrived/Left */
+ ISPASYNC_LOGGED_INOUT, /* FC Object Logged In/Out */
ISPASYNC_TARGET_MESSAGE, /* target message */
ISPASYNC_TARGET_EVENT, /* target asynchronous event */
ISPASYNC_TARGET_ACTION /* other target command action */
@@ -534,7 +534,13 @@ int isp_async __P((struct ispsoftc *, ispasync_t, void *));
/*
* Platform Dependent Error and Debug Printout
*/
+#ifdef __GNUC__
+void isp_prt __P((struct ispsoftc *, int level, const char *, ...))
+ __attribute__((__format__(__printf__,3,4)));
+#else
void isp_prt __P((struct ispsoftc *, int level, const char *, ...));
+#endif
+
#define ISP_LOGALL 0x0 /* log always */
#define ISP_LOGCONFIG 0x1 /* log configuration messages */
#define ISP_LOGINFO 0x2 /* log informational messages */